@@ -10,6 +10,8 @@ import query_toolkits.utils as utils
 
 
 class Extractor:
+    def __init__(self):
+        self.unit_transform = utils._read_table()
 
     def _check_time_valid(self, word):
         m = re.match("\d+$", word)
@@ -238,12 +240,10 @@ class Extractor:
         return final_res
 
 
-
-
     def extract_number(self, cut_res):
-        direct_transform = utils.direct_transform
+        #direct_transform = utils.direct_transform
+        direct_transform = self.unit_transform
         general_transform = utils.general_transform
-
         #分词、词性
         candidates = []
         candidate = ""
@@ -251,7 +251,7 @@ class Extractor:
         end_index = 0
         for i, (word, flag) in enumerate(cut_res):
             end_index += len(word)
-            if flag in ("m", "q", "mq") or word.isdigit():
+            if flag in ("m", "q", "mq") or word.isdigit() or (flag in ("x", "eng") and word in direct_transform):
                 if not start_index:
                     start_index = end_index - len(word)
                 candidate += word
@@ -267,6 +267,7 @@ class Extractor:
                 candidate = ""
         if candidate != "":
             candidates.append((candidate, start_index, end_index))
+
         final_res = []
         #再正则处理
         pattern = "^([0-9]+(\.[0-9]+)?)([^0-9]+)$"
@@ -323,12 +324,12 @@ class Extractor:
 #     "涨了15%的股票",
 #     "10万亿元",
 #     "234立方厘米",
-#     "目标是5个百分点"
+#     "目标是5个百分点",
+#     "5L"
 # ]
 #
 # for text in li:
-#     cut_res = psg.lcut(text)
-#     print(cut_res)
+#     cut_res = psg.lcut(text.lower())
 #     res = et.extract_number(cut_res)
 #     print(res)
 
